#!/bin/bash
# Set the following to the directory where you have the GST plugins
GST_SRC=/home/root/gst
# The GStreamer registry is preserved between reboots, so you can
# set this to 0 if you have updated the registry at least once.
GST_UPDATE_REGISTRY=1

# Override the GST plugins that were nerfed by LG
if [[ ! -d /tmp/gstreamer-1.0 ]]; then
  echo "Installing /usr/lib/gstreamer-1.0/ overrides"
  mkdir /tmp/work
  mkdir /tmp/gstreamer-1.0
  if [[ -f $GST_SRC/libgstmatroska.so ]]; then
    cp $GST_SRC/libgstmatroska.so /tmp/gstreamer-1.0/
  fi
  if [[ -f $GST_SRC/libgstaudioparsers.so ]]; then
    cp $GST_SRC/libgstaudioparsers.so /tmp/gstreamer-1.0/
  fi
  if [[ -f $GST_SRC/libgstlibav.so ]]; then
    cp $GST_SRC/libgstlibav.so /tmp/gstreamer-1.0/libgstlibav.so
  fi
  mount -n -t overlay overlay -o lowerdir=/usr/lib/gstreamer-1.0,upperdir=/tmp/gstreamer-1.0,workdir=/tmp/work /usr/lib/gstreamer-1.0
fi

# Override /etc/gst/gstcool.conf
if [[ ! -f /tmp/gstcool.conf ]]; then
  echo "Installing /etc/gst/gstcool.conf override"
  if [[ -f /etc/gst/gstcool.conf ]]; then
    sed "s/avdec_dca=0/avdec_dca=290/" /etc/gst/gstcool.conf > /tmp/gstcool.conf 
    mount -n --bind /tmp/gstcool.conf /etc/gst/gstcool.conf
  fi
fi

# Update the GST registry so that the DTS decoder is recognized
if [[ $GST_UPDATE_REGISTRY -gt 0 ]]; then
  echo "Updating GStreamer registry file"
  eval $(nyx-cmd OSInfo query --format=shell webos_release webos_build_id)
  GST_REGISTRY_STAMP="${GST_REGISTRY_1_0}.done.$webos_release-$webos_build_id"
  GST_REGISTRY_UPDATE=yes /usr/bin/gst-inspect-1.0 > /var/tmp/gst-inspect.log
  chmod 666 ${GST_REGISTRY_1_0}
  chown :compositor ${GST_REGISTRY_1_0}
  rm -f ${GST_REGISTRY_1_0}.done.*
  touch ${GST_REGISTRY_STAMP}
fi
